<img src=https://image.ibb.co/b1P0de/Screen_Shot_2018_09_30_at_4_36_27_PM.png align=left><br><br>

A python package that implements several pseudo, quasi, and true, including quantum random methods into a unified single-line command interface.

## methods

- Quantum
- Ambient sound
- Halton sequence
- Korobov matrix
- Latin hypercube
- Latin hypercube with Sudoku style constraint
- Improved Latin hypercube (very slow)
- Uniform mersenne
- Uniform cryptographically sound

## visualization

- 1d plot
- 2d plot

## todo

- test degree of randomness for each method
- add degree of randomness test methods
- add more random methods
- add shuffle function
- add support for strings
